import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/page_wrapper.dart';

class BottomSheetExample extends StatelessWidget {
  const BottomSheetExample({
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final double screenHeight = MediaQuery.of(context).size.height;
    const Size appBarHeiht = const Size.fromHeight(100.0);
    final double bottomSheetHeight = screenHeight - appBarHeiht.height;

    return PageWrapper(
      title: 'Bottom Sheet',
      child: Center(
        child: SeniorButton(
          label: 'Mostrar',
          onPressed: () {
            SeniorBottomSheet.showBottomSheet(
              enableDrag: true,
              isDismissible: true,
              height: bottomSheetHeight,
              context: context,
              hasCloseButton: true,
              title: 'Busque um colega que você deseja enviar um feedback',
              onTapCloseButton: () {
                Navigator.pop(context);
              },
              content: <Widget>[
                Expanded(
                  child: Container(
                    height: 400.0,
                    child: ListView.separated(
                      separatorBuilder: (_, __) => const SizedBox(
                        height: SeniorSpacing.small,
                      ),
                      itemCount: 3,
                      itemBuilder: (_, index) {
                        return Consumer<ThemeRepository>(
                          builder: (context, repository, child) =>
                              SeniorText.body(index.toString()),
                        );
                      },
                    ),
                  ),
                ),
              ],
            );
          },
        ),
      ),
    );
  }
}
