import 'package:flutter/material.dart';

import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class ButtonExample extends StatefulWidget {
  const ButtonExample({Key? key}) : super(key: key);

  @override
  _ButtonExampleState createState() => _ButtonExampleState();
}

class _ButtonExampleState extends State<ButtonExample> {
  bool _disabled = false;

  void _showSnackbar() {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.success(
        message: 'Documento enviado',
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Button',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: SeniorSpacing.normal),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !_disabled,
                onChanged: (value) {
                  if (value == null) {
                    return;
                  }
                  setState(() {
                    _disabled = !value;
                  });
                },
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(SeniorSpacing.normal),
                child: Column(
                  children: [
                    Panel(
                      title: 'Botão primário',
                      child: SeniorButton.primary(
                        label: 'Enviar',
                        onPressed: _showSnackbar,
                        disabled: _disabled,
                        icon: FontAwesomeIcons.rocket,
                      ),
                    ),
                    Panel(
                      title: 'Botão secundário',
                      child: SeniorButton.secondary(
                        label: 'Enviar',
                        onPressed: _showSnackbar,
                        disabled: _disabled,
                        icon: FontAwesomeIcons.rocket,
                      ),
                    ),
                    Panel(
                      title: 'Botão ghost',
                      child: SeniorButton.ghost(
                        label: 'Enviar',
                        onPressed: _showSnackbar,
                        disabled: _disabled,
                        icon: FontAwesomeIcons.rocket,
                      ),
                    ),
                    Panel(
                      title: 'Botão outlined',
                      child: SeniorButton.primary(
                        label: 'Enviar',
                        onPressed: _showSnackbar,
                        disabled: _disabled,
                        icon: FontAwesomeIcons.rocket,
                        outlined: true,
                      ),
                    ),
                    Panel(
                      title: 'Botão danger',
                      child: SeniorButton.primary(
                        label: 'Enviar',
                        onPressed: _showSnackbar,
                        disabled: _disabled,
                        icon: FontAwesomeIcons.rocket,
                        outlined: true,
                        danger: true,
                      ),
                    ),
                    Panel(
                      title: 'Botão ocupado',
                      child: Column(
                        children: [
                          Padding(
                            padding: const EdgeInsets.all(SeniorSpacing.xsmall),
                            child: SeniorButton.primary(
                              label: 'Enviar',
                              onPressed: _showSnackbar,
                              disabled: _disabled,
                              icon: FontAwesomeIcons.rocket,
                              busy: true,
                              busyMessage: 'Enviando...',
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.all(SeniorSpacing.xsmall),
                            child: SeniorButton.secondary(
                              label: 'Enviar',
                              onPressed: _showSnackbar,
                              disabled: _disabled,
                              icon: FontAwesomeIcons.rocket,
                              busy: true,
                              busyMessage: 'Enviando...',
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.all(SeniorSpacing.xsmall),
                            child: SeniorButton.ghost(
                              label: 'Enviar',
                              onPressed: _showSnackbar,
                              disabled: _disabled,
                              icon: FontAwesomeIcons.rocket,
                              busy: true,
                              busyMessage: 'Enviando...',
                            ),
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
