import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:intl/date_symbol_data_local.dart';
import 'package:intl/intl.dart' show DateFormat;
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/page_wrapper.dart';

class CalendarExemple extends StatefulWidget {
  const CalendarExemple({Key? key}) : super(key: key);

  @override
  State<CalendarExemple> createState() => _CalendarExempleState();
}

class _CalendarExempleState extends State<CalendarExemple> {
  DateTime _currentDate = DateTime.now();
  bool isCircle = false;
  bool isSquare = false;
  bool isTriangle = false;
  bool isTriangleDown = false;
  bool isWeekFormatMinHeight = true;
  String _headerTitle = DateFormat('dd/MM/yyyy').format(DateTime.now()) +
      ' até ' +
      DateFormat('dd/MM/yyyy').format(DateTime.now());
  final String _selectedDate = DateTime.now().toUtc().toString();

  SeniorCalendarFormat format = SeniorCalendarFormat.week;

  final EventList<Event> _markedDateMap = EventList<Event>(
    events: {
      DateTime(DateTime.now().year, DateTime.now().month, 15): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 15),
          formsDefault: [SeniorFormsEnum.CIRCLE],
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month, 12): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 12),
          formsDefault: [
            SeniorFormsEnum.CIRCLE,
            SeniorFormsEnum.SQUARE,
            SeniorFormsEnum.TRIANGLE,
          ],
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month, 17): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 17),
          formsDefault: [
            SeniorFormsEnum.CIRCLE,
            SeniorFormsEnum.SQUARE,
            SeniorFormsEnum.TRIANGLE,
            SeniorFormsEnum.TRIANGLE_DOWN
          ],
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month, 19): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 19),
          formsDefault: [
            SeniorFormsEnum.CIRCLE,
            SeniorFormsEnum.SQUARE,
          ],
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month, 23): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 23),
          formsDefault: [
            SeniorFormsEnum.TRIANGLE,
            SeniorFormsEnum.TRIANGLE_DOWN
          ],
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month + 1, 3): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month + 1, 3),
          formsDefault: [SeniorFormsEnum.CIRCLE, SeniorFormsEnum.TRIANGLE_DOWN],
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month + 1, 1): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month + 1, 1),
          formsDefault: [
            SeniorFormsEnum.CIRCLE,
          ],
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month + 1, 19): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month + 1, 19),
          formsDefault: [SeniorFormsEnum.CIRCLE, SeniorFormsEnum.TRIANGLE_DOWN],
        ),
      ],
    },
  );
  final EventList<Event> _markedDateBuildMap = EventList<Event>(
    events: {
      DateTime(DateTime.now().year, DateTime.now().month, 15): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 15),
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month, 12): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 12),
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month, 17): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 17),
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month, 19): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 19),
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month, 23): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month, 23),
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month + 1, 3): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month + 1, 3),
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month + 1, 1): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month + 1, 1),
        ),
      ],
      DateTime(DateTime.now().year, DateTime.now().month + 1, 19): [
        Event(
          date: DateTime(DateTime.now().year, DateTime.now().month + 1, 19),
        ),
      ],
    },
  );
  @override
  void initState() {
    initializeDateFormatting();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final TextEditingController editingController = TextEditingController();
    const String locate = 'pt-BR';
    late DateFormat localeDate;
    localeDate = DateFormat('d/MM/yyyy', locate);

    return PageWrapper(
      title: 'Calendar',
      child: SingleChildScrollView(
        child: Column(
          children: [
            SeniorCalendar(
              showStrokeTop: false,
              markedDateMap: _markedDateMap,
              inactiveYesterdays: true,
              calendarTitle: 'Selecione a data',
              sixWeekMonthsEnforced: true,
              selectedDay: DateTime.now().add(
                const Duration(days: 5),
              ),
              firstDay: DateTime(DateTime.now().year, 1, 1),
              lastDay: DateTime(DateTime.now().year, 12, 31),
              highlightToday: true,
              onPageChanged: (focusedDay) {
                log(focusedDay.toString());
              },
              locale: 'pt_BR',
              bottomText: 'Selecione uma data no calendário',
              calendarBuilders: SeniorCalendarBuilder(
                dowBuilder: (context, day) {
                  return Center(
                    child: SeniorText.small(
                      DateFormat.E(locate).format(day).toUpperCase(),
                      style: SeniorTypography.label(color: Colors.grey),
                    ),
                  );
                },
                outsideBuilder: (context, date, focusedDay) {
                  return const SizedBox.shrink();
                },
                selectedBuilder: (context, date, focusedDay) {
                  return Column(
                    children: [
                      Container(
                        height: 32,
                        width: 32,
                        decoration: const BoxDecoration(
                          shape: BoxShape.circle,
                          color: Colors.red,
                        ),
                      ),
                      SeniorText.small(date.day.toString()),
                    ],
                  );
                },
                defaultBuilder: (context, date, focusedDay) {
                  return Column(
                    children: [
                      Container(
                        height: 32,
                        width: 32,
                        decoration: const BoxDecoration(
                          shape: BoxShape.circle,
                          color: Colors.red,
                        ),
                      ),
                      SeniorText.small(date.day.toString()),
                    ],
                  );
                },
                todayBuilder: (context, date, focusedDay) {
                  return Column(
                    children: [
                      Container(
                        height: 32,
                        width: 32,
                        decoration: const BoxDecoration(
                          shape: BoxShape.circle,
                          color: Colors.red,
                        ),
                      ),
                      SeniorText.small(date.day.toString()),
                    ],
                  );
                },
              ),
            ),
            const Padding(
              padding: EdgeInsets.all(25),
              child: Divider(
                thickness: 5,
              ),
            ),
            SeniorTextField(
              controller: editingController,
              label: localeDate.format(_currentDate),
              maxLines: 1,
              leftIcon: FontAwesomeIcons.rocket,
            ),
            SeniorButton(
              label: 'Selecione a data',
              onPressed: () {
                SeniorCalendar(
                  inactiveYesterdays: true,
                  showStrokeTop: true,
                  calendarTitle: 'Selecione a data',
                  selectedDay: _currentDate,
                  firstDay: DateTime(DateTime.now().year, 1, 1),
                  lastDay: DateTime(DateTime.now().year, 12, 31),
                  highlightToday: true,
                  locale: locate,
                  bottomText: 'Selecione uma data no calendário',
                  onDaySelected: (date) {
                    setState(() => _currentDate = date);
                    Navigator.pop(context);
                  },
                ).pickCalendar(context);
              },
            ),
            const Padding(
              padding: EdgeInsets.all(25),
              child: Divider(
                thickness: 5,
              ),
            ),
            SeniorButton(
              label: 'Marcar Data',
              onPressed: () {
                final List<SeniorFormsEnum> forms = [];

                if (isCircle) {
                  forms.add(SeniorFormsEnum.CIRCLE);
                }
                if (isSquare) {
                  forms.add(SeniorFormsEnum.SQUARE);
                }
                if (isTriangle) {
                  forms.add(SeniorFormsEnum.TRIANGLE);
                }
                if (isTriangleDown) {
                  forms.add(SeniorFormsEnum.TRIANGLE_DOWN);
                }
                _markedDateBuildMap.add(
                  _currentDate,
                  Event(
                    date: _currentDate,
                  ),
                );
                _markedDateMap.add(
                  _currentDate,
                  Event(
                    date: _currentDate,
                    formsDefault: forms,
                  ),
                );
                setState(() {});
              },
            ),
            Padding(
              padding: const EdgeInsets.only(top: 25, left: 25),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  SeniorCheckbox(
                    value: isCircle,
                    onChanged: (value) => setState(() => isCircle = value!),
                    title: 'Marcação Círculo',
                  ),
                  SeniorCheckbox(
                    value: isSquare,
                    onChanged: (value) => setState(() => isSquare = value!),
                    title: 'Marcação Quadrado',
                  ),
                  SeniorCheckbox(
                    value: isTriangle,
                    onChanged: (value) => setState(() => isTriangle = value!),
                    title: 'Marcação Triângulo',
                  ),
                  SeniorCheckbox(
                    value: isTriangleDown,
                    onChanged: (value) =>
                        setState(() => isTriangleDown = value!),
                    title: 'Marcação Triângulo para baixo',
                  ),
                ],
              ),
            ),
            const Padding(
              padding: EdgeInsets.all(25),
              child: Divider(
                thickness: 5,
              ),
            ),
            SeniorText.h4('Exemplo com Default Marked Day'),
            SeniorCalendar(
              showStrokeTop: false,
              markedDateMap: _markedDateMap,
              inactiveYesterdays: true,
              calendarTitle: 'Selecione a data',
              selectedDay: DateTime.now(),
              firstDay: DateTime(DateTime.now().year, 1, 1),
              lastDay: DateTime(DateTime.now().year, 12, 31),
              highlightToday: true,
              onPageChanged: (focusedDay) {
                log(focusedDay.toString());
              },
              locale: 'pt_BR',
              bottomText: 'Selecione uma data no calendário',
            ),
            const Padding(
              padding: EdgeInsets.all(25),
              child: Divider(
                thickness: 5,
              ),
            ),
            SeniorText.h4('Exemplo com builds Marked Day'),
            SeniorCalendar(
              showStrokeTop: false,
              markedDateMap: _markedDateBuildMap,
              inactiveYesterdays: true,
              calendarTitle: 'Selecione a data',
              selectedDay: DateTime.now(),
              firstDay: DateTime(DateTime.now().year, 1, 1),
              lastDay: DateTime(DateTime.now().year, 12, 31),
              highlightToday: true,
              locale: 'pt_BR',
              bottomText: 'Selecione uma data no calendário',
              // buildMarkedDayWidget: const Center(
              //     child: Icon(
              //   Icons.check,
              //   color: Colors.red,
              //   size: 14,
              // )),
            ),
            const Padding(
              padding: EdgeInsets.all(25),
              child: Divider(
                thickness: 5,
              ),
            ),
            SeniorText.h4('Exemplo com mudança de visualização'),
            SeniorText.label(_selectedDate),
            SeniorCalendar(
              dateConnective: 'até',
              showStrokeTop: false,
              selectedDay: _currentDate,
              firstDay: DateTime(DateTime.now().year, 1, 15),
              lastDay: DateTime(DateTime.now().year, 12, 15),
              highlightToday: true,
              locale: 'pt_BR',
              onDaySelected: (date) {
                setState(() => _currentDate = date);
              },
              calendarFormat: format,
              onChangeFormat: (format) {
                setState(() {
                  this.format = format;
                });
              },
            ),
            SeniorText.h4('Exemplo de uso do cabeçalho'),
            SeniorCalendarHeader(
              headerTitle: _headerTitle,
              onLeftButtonPressed: () => {
                setState(() {
                  _headerTitle = 'Left Button pressed';
                })
              },
              onRightButtonPressed: () => {
                setState(() {
                  _headerTitle = 'Right Button pressed';
                })
              },
              showHeader: true,
            ),
          ],
        ),
      ),
    );
  }
}
