import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class CarouselSliderExample extends StatefulWidget {
  const CarouselSliderExample({Key? key}) : super(key: key);

  @override
  State<CarouselSliderExample> createState() => _CarouselSliderExampleState();
}

class _CarouselSliderExampleState extends State<CarouselSliderExample> {
  String _option = 'people';
  int _initialPage = _peopleInitialPage;
  Key _key = UniqueKey();

  List<ImageProvider> _getList(String option) {
    switch (option) {
      case 'people':
        return _peopleImages;
      case 'pets':
        return _petsImages;
      case 'empty':
      default:
        return _empty;
    }
  }

  void _restartApp() {
    setState(() {
      _key = UniqueKey();
    });
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Carousel Slider',
      child: KeyedSubtree(
        key: _key,
        child: Column(
          children: [
            Padding(
              padding: const EdgeInsets.only(top: SeniorSpacing.normal),
              child: Row(
                children: [
                  Flexible(
                    child: SeniorRadioButton(
                      groupValue: _option,
                      onChanged: (value) {
                        setState(() {
                          _option = value as String;
                          _initialPage = _peopleInitialPage;
                        });
                        _restartApp();
                      },
                      title: 'People',
                      value: 'people',
                    ),
                  ),
                  Flexible(
                    child: SeniorRadioButton(
                      groupValue: _option,
                      onChanged: (value) {
                        setState(() {
                          _option = value as String;
                          _initialPage = _petsInitialPage;
                        });
                        _restartApp();
                      },
                      title: 'Pets',
                      value: 'pets',
                    ),
                  ),
                  Flexible(
                    child: SeniorRadioButton(
                      groupValue: _option,
                      onChanged: (value) {
                        setState(() {
                          _option = value as String;
                          _initialPage = _emptyInitialPage;
                        });
                        _restartApp();
                      },
                      title: 'Empty',
                      value: 'empty',
                    ),
                  ),
                ],
              ),
            ),
            Expanded(
              child: SeniorCarouselSlider(
                emptyLabel: 'Registre sua foto aqui',
                images: _getList(_option),
                initialPage: _initialPage,
                onDelete: (int index) {
                  final list = _getList(_option);
                  setState(() {
                    list.removeAt(index);
                  });
                },
                deleteDialogDefinition: SeniorModalDefinitions(
                  title: 'Excluir foto da galeria?',
                  content:
                      'Você tem certeza que deseja excluir a foto da galeria? Ao fazer isso ela será perdida.',
                  confirmLabel: 'Sim',
                  cancelLabel: 'Cancelar',
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}

final List<ImageProvider> _peopleImages = [
  'https://images.pexels.com/photos/13075751/pexels-photo-13075751.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=1',
  'https://images.pexels.com/photos/12502186/pexels-photo-12502186.jpeg?auto=compress&cs=tinysrgb&w=400&lazy=load',
  'https://images.pexels.com/photos/13014413/pexels-photo-13014413.jpeg?auto=compress&cs=tinysrgb&w=400&lazy=load',
  'https://images.pexels.com/photos/9629901/pexels-photo-9629901.jpeg?auto=compress&cs=tinysrgb&w=400&lazy=load',
  'https://images.pexels.com/photos/11762028/pexels-photo-11762028.jpeg?auto=compress&cs=tinysrgb&w=400&lazy=load',
  'https://images.pexels.com/photos/11696932/pexels-photo-11696932.jpeg?auto=compress&cs=tinysrgb&w=1600&lazy=load',
  'https://images.pexels.com/photos/7406066/pexels-photo-7406066.jpeg?auto=compress&cs=tinysrgb&w=1600&lazy=load',
  'https://images.pexels.com/photos/8916199/pexels-photo-8916199.jpeg?auto=compress&cs=tinysrgb&w=1600&lazy=load',
].map((link) => NetworkImage(link)).toList();

final List<ImageProvider> _petsImages = [
  'https://images.pexels.com/photos/1108099/pexels-photo-1108099.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/2071873/pexels-photo-2071873.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/895259/pexels-photo-895259.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/2194261/pexels-photo-2194261.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/1390361/pexels-photo-1390361.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/96938/pexels-photo-96938.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/169524/pexels-photo-169524.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/2061057/pexels-photo-2061057.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/92380/pexels-photo-92380.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/2071881/pexels-photo-2071881.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/803766/pexels-photo-803766.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/236660/pexels-photo-236660.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/2252311/pexels-photo-2252311.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/121920/pexels-photo-121920.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/164446/pexels-photo-164446.jpeg?auto=compress&cs=tinysrgb&w=1600',
  'https://images.pexels.com/photos/596135/pexels-photo-596135.jpeg?auto=compress&cs=tinysrgb&w=1600',
].map((link) => NetworkImage(link)).toList();

final List<ImageProvider> _empty = [];

const int _peopleInitialPage = 3;
const int _petsInitialPage = 5;
const int _emptyInitialPage = 0;
