import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class CheckboxExample extends StatefulWidget {
  const CheckboxExample({Key? key}) : super(key: key);

  @override
  _CheckboxExampleState createState() => _CheckboxExampleState();
}

class _CheckboxExampleState extends State<CheckboxExample> {
  bool _isDisabled = false;
  bool _optionOne = false;
  bool _optionTwo = false;
  bool _optionThree = false;
  bool _optionFour = false;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Checkbox',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !_isDisabled,
                onChanged: (value) {
                  if (value == null) {
                    return;
                  }
                  setState(() {
                    _isDisabled = !value;
                  });
                },
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Panel(
                      title: 'Normal',
                      child: Column(
                        children: [
                          SeniorCheckbox(
                            title: 'Matutino',
                            value: _optionOne,
                            actionOnTitle: false,
                            extraTapMargin: 10.0,
                            onChanged: (value) {
                              if (value == null) {
                                return;
                              }
                              setState(() {
                                _optionOne = value;
                              });
                            },
                            disabled: _isDisabled,
                          ),
                          SeniorCheckbox(
                            title:
                                'Texto muito grande que não cabe na tela para ver quebrar e ficar com várias linhas',
                            value: _optionOne,
                            actionOnTitle: false,
                            extraTapMargin: 10.0,
                            onChanged: (value) {
                              if (value == null) {
                                return;
                              }
                              setState(() {
                                _optionOne = value;
                              });
                            },
                            disabled: _isDisabled,
                          ),
                          SeniorCheckbox(
                            title: 'Vespertino',
                            value: _optionTwo,
                            actionOnTitle: false,
                            extraTapMargin: 25.0,
                            onChanged: (value) {
                              if (value == null) {
                                return;
                              }
                              setState(() {
                                _optionTwo = value;
                              });
                            },
                            disabled: _isDisabled,
                          ),
                          SeniorCheckbox(
                            title: 'Noturno',
                            value: _optionThree,
                            actionOnTitle: true,
                            onChanged: (value) {
                              if (value == null) {
                                return;
                              }
                              setState(() {
                                _optionThree = value;
                              });
                            },
                            disabled: _isDisabled,
                          ),
                        ],
                      ),
                    ),
                    Panel(
                      title: 'Sem label',
                      child: SeniorCheckbox(
                        value: _optionOne,
                        onChanged: (value) {
                          if (value == null) {
                            return;
                          }
                          setState(() {
                            _optionOne = value;
                          });
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Botões em linha',
                      child: Row(
                        children: [
                          Expanded(
                            child: SeniorCheckbox(
                              title: 'Esquerda',
                              value: _optionOne,
                              onChanged: (value) {
                                if (value == null) {
                                  return;
                                }
                                setState(() {
                                  _optionOne = value;
                                });
                              },
                              disabled: _isDisabled,
                            ),
                          ),
                          Expanded(
                            child: SeniorCheckbox(
                              title: 'Centro',
                              value: _optionTwo,
                              onChanged: (value) {
                                if (value == null) {
                                  return;
                                }
                                setState(() {
                                  _optionTwo = value;
                                });
                              },
                              disabled: _isDisabled,
                            ),
                          ),
                          Expanded(
                            child: SeniorCheckbox(
                              title: 'Direita',
                              value: _optionThree,
                              onChanged: (value) {
                                if (value == null) {
                                  return;
                                }
                                setState(() {
                                  _optionThree = value;
                                });
                              },
                              disabled: _isDisabled,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Panel(
                      title: 'Botões em colunas separadas',
                      child: Column(
                        children: [
                          Row(
                            children: [
                              Expanded(
                                child: SeniorCheckbox(
                                  title: 'Brasil',
                                  value: _optionOne,
                                  onChanged: (value) {
                                    if (value == null) {
                                      return;
                                    }
                                    setState(() {
                                      _optionOne = value;
                                    });
                                  },
                                  disabled: _isDisabled,
                                ),
                              ),
                              Expanded(
                                child: SeniorCheckbox(
                                  title: 'Argentina',
                                  value: _optionTwo,
                                  onChanged: (value) {
                                    if (value == null) {
                                      return;
                                    }
                                    setState(() {
                                      _optionTwo = value;
                                    });
                                  },
                                  disabled: _isDisabled,
                                ),
                              ),
                            ],
                          ),
                          Row(
                            children: [
                              Expanded(
                                child: SeniorCheckbox(
                                  title: 'Colômbia',
                                  value: _optionThree,
                                  onChanged: (value) {
                                    if (value == null) {
                                      return;
                                    }
                                    setState(() {
                                      _optionThree = value;
                                    });
                                  },
                                  disabled: _isDisabled,
                                ),
                              ),
                              Expanded(
                                child: SeniorCheckbox(
                                  title: 'Peru',
                                  value: _optionFour,
                                  onChanged: (value) {
                                    if (value == null) {
                                      return;
                                    }
                                    setState(() {
                                      _optionFour = value;
                                    });
                                  },
                                  disabled: _isDisabled,
                                ),
                              ),
                            ],
                          )
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
