import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class DropdownButtonExample extends StatefulWidget {
  const DropdownButtonExample({Key? key}) : super(key: key);

  @override
  _DropdownButtonExampleState createState() => _DropdownButtonExampleState();
}

class _DropdownButtonExampleState extends State<DropdownButtonExample> {
  bool _isDisabled = false;
  List<dynamic>? _values;
  String? _value1;
  String? _value2;
  String? _value3;
  String? _value4;
  int? valueInt;

  void showMessageSnackbar(BuildContext context, String message) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.message(
        message: message,
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Dropdown Button',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar campos',
                value: !_isDisabled,
                onChanged: (value) {
                  if (value == null) {
                    return;
                  }
                  setState(() {
                    _isDisabled = !value;
                  });
                },
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Multiselect',
                      child: SeniorMultidropdownButton(
                        label: 'Sabores',
                        items: [
                          const SeniorDropdownButtonItem(
                            value: 'calabresa',
                            title: 'Calabresa',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'marguerita',
                            title: 'Marguerita',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'mucarela',
                            title: 'Muçarela',
                          ),
                        ],
                        validator: (values) {
                          return values == null || values.isEmpty
                              ? 'Selecione pelo menos um sabor'
                              : null;
                        },
                        values: _values,
                        helper: 'Selecione seus sabores de pizza',
                        onSelected: (values) {
                          showMessageSnackbar(
                            context,
                            values.isNotEmpty
                                ? '$values selecionados'
                                : 'Nenhum item selecionado',
                          );
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Multiselect with select all option',
                      child: SeniorMultidropdownButton(
                        label: 'Sabores',
                        selectAllConfig: const SelectAllConfig(
                          selectAllLabel: 'Marcar todos',
                          unselectAllLabel: 'Desmarcar todos',
                        ),
                        items: [
                          const SeniorDropdownButtonItem(
                            value: 'calabresa',
                            title: 'Calabresa',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'marguerita',
                            title: 'Marguerita',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'mucarela',
                            title: 'Muçarela',
                          ),
                        ],
                        validator: (values) {
                          return values == null || values.isEmpty
                              ? 'Selecione pelo menos um sabor'
                              : null;
                        },
                        values: _values,
                        helper: 'Selecione seus sabores de pizza',
                        onSelected: (values) {
                          showMessageSnackbar(
                            context,
                            values.isNotEmpty
                                ? '$values selecionados'
                                : 'Nenhum item selecionado',
                          );
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Normal',
                      child: SeniorDropdownButton(
                        label: 'País de origem',
                        items: [
                          const SeniorDropdownButtonItem(
                            value: 'brasil',
                            title: 'Brasil',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'argentina',
                            title: 'Argentina',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'uruguai',
                            title: 'Uruguai',
                          ),
                        ],
                        value: _value1,
                        helper: 'Selecione seu país de origem',
                        onSelected: (value) {
                          showMessageSnackbar(
                            context,
                            value != null
                                ? '$value selecionado'
                                : 'Nenhum item selecionado',
                          );
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Sem String',
                      child: SeniorDropdownButton<int?>(
                        label: 'Número',
                        items: [
                          const SeniorDropdownButtonItem(
                            value: 1,
                            title: 'Brasil',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 2,
                            title: 'Argentina',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 3,
                            title: 'Uruguai',
                          ),
                        ],
                        value: valueInt,
                        helper: 'Selecione o número',
                        onSelected: (value) {
                          setState(() {
                            valueInt = value;
                          });
                          showMessageSnackbar(
                            context,
                            value != null
                                ? '$value selecionado'
                                : 'Nenhum item selecionado',
                          );
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Ícone à esquerda',
                      child: SeniorDropdownButton(
                        label: 'Missão espacial',
                        icon: FontAwesomeIcons.rocket,
                        items: [
                          const SeniorDropdownButtonItem(
                            value: 'apollo11',
                            title: 'Apollo 11',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'apollo12',
                            title: 'Apollo 12',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'apollo14',
                            title: 'Apollo 14',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'apollo15',
                            title: 'Apollo 15',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'apollo16',
                            title: 'Apollo 16',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'apollo17',
                            title: 'Apollo 17',
                          ),
                        ],
                        value: _value2,
                        onSelected: (value) {
                          showMessageSnackbar(
                            context,
                            value != null
                                ? '$value selecionado'
                                : 'Nenhum item selecionado',
                          );
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Sem linha',
                      child: SeniorDropdownButton(
                        label: 'Tecnologia',
                        items: [
                          const SeniorDropdownButtonItem(
                            value: 'angular',
                            title: 'Angular',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'flutter',
                            title: 'Flutter',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'Spring',
                            title: 'Spring',
                          ),
                        ],
                        value: _value3,
                        showUnderline: false,
                        onSelected: (value) {
                          showMessageSnackbar(
                            context,
                            value != null
                                ? '$value selecionado'
                                : 'Nenhum item selecionado',
                          );
                        },
                        disabled: _isDisabled,
                      ),
                    ),
                    Panel(
                      title: 'Com validator',
                      child: SeniorDropdownButton(
                        label: 'O que é Via Láctea',
                        icon: FontAwesomeIcons.rocket,
                        items: [
                          const SeniorDropdownButtonItem(
                            value: 'marca-de-leite',
                            title: 'Marca de Leite',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'civilizacao',
                            title: 'Civilização Antiga',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'carro',
                            title: 'Carro',
                          ),
                          const SeniorDropdownButtonItem(
                            value: 'galaxia',
                            title: 'Galáxia',
                          ),
                        ],
                        value: _value4,
                        onSelected: (value) {
                          showMessageSnackbar(
                            context,
                            value != null
                                ? '$value selecionado'
                                : 'Nenhum item selecionado',
                          );
                        },
                        validator: (value) =>
                            value != 'galaxia' ? 'Errou!' : null,
                        disabled: _isDisabled,
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
