import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class ExpansionPanelExample extends StatefulWidget {
  const ExpansionPanelExample({Key? key}) : super(key: key);

  @override
  _ExpansionPanelExampleState createState() => _ExpansionPanelExampleState();
}

Widget buildStars(int value) {
  final List<Widget> stars = [];

  for (int i = 0; i < value; i++) {
    stars.add(
      const Icon(
        FontAwesomeIcons.star,
        size: SeniorIconSize.small,
      ),
    );
  }

  return Row(
    children: stars,
  );
}

class _ExpansionPanelExampleState extends State<ExpansionPanelExample> {
  Widget buildPanelOne(bool isLightTheme) {
    return SeniorExpansionPanelList(
      list: infoOne
          .map(
            (e) => SeniorPanelData(
              headerInfo: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  SeniorText.label(e['user']),
                  SeniorRating(
                    initialRating: e['evaluation'].toDouble(),
                    itemCount: e['evaluation'].toInt(),
                    onRatingUpdate: (value) {},
                    ignoreGestures: true,
                  ),
                ],
              ),
              expandedInfo: SeniorText.label(e['note']),
              severityColor: e['evaluation'] >= 3
                  ? SeniorColors.manchesterColorGreen
                  : SeniorColors.manchesterColorRed,
              isExpanded: e['is_expanded'],
            ),
          )
          .toList(),
      expansionCallback: (index, value) {
        setState(() {
          infoOne[index]['is_expanded'] = !value;
        });
      },
    );
  }

  Widget buildPanelTwo(bool isLightTheme) {
    final List<dynamic> info = infoTwo;

    return SeniorExpansionPanelList(
      list: info
          .map(
            (e) => SeniorPanelData(
              headerInfo: SeniorCheckbox(
                title: e['title'],
                value: e['is_checked'],
                onChanged: (value) {
                  if (value == null) {
                    return;
                  }
                  setState(() {
                    e['is_checked'] = value;
                  });
                },
              ),
              expandedInfo: Column(
                crossAxisAlignment: CrossAxisAlignment.stretch,
                children: [
                  Container(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.small('Solicitante'),
                        SeniorText.body(e['requester']),
                      ],
                    ),
                  ),
                  Container(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.small('Custo'),
                        SeniorText.body('R\$ ${e['cost']}'),
                      ],
                    ),
                  ),
                ],
              ),
              actions: [
                SeniorButton.secondary(
                  label: 'Negar',
                  onPressed: () {},
                ),
                SeniorButton.primary(
                  label: 'Aprovar',
                  onPressed: () {},
                ),
              ],
              isExpanded: e['is_expanded'],
            ),
          )
          .toList(),
      expansionCallback: (index, value) {
        setState(() {
          info[index]['is_expanded'] = !value;
        });
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Expansion Panel',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(SeniorSpacing.normal),
          child: Consumer<ThemeRepository>(
            builder: (context, repository, child) => Column(
              children: [
                Panel(
                  title: 'Título e ícones',
                  child: buildPanelOne(repository.isLightTheme()),
                ),
                Panel(
                  title: 'Checkbox',
                  child: buildPanelTwo(repository.isLightTheme()),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

final List<dynamic> infoOne = [
  {
    'evaluation': 5,
    'user': 'Maria Aparecida da Silva',
    'note':
        'O sistema é muito responsivo e a sua interface é muito bonita e intuitiva. Uso todos os dias nas minhas atividades diárias.',
    'is_expanded': false,
  },
  {
    'evaluation': 2,
    'user': 'Francisco Golçalves Filho',
    'note':
        'Tenho muitos travamentos e não atende às minhas necessidades. Por favor ajustem isso.',
    'is_expanded': false,
  },
];

final List<dynamic> infoTwo = [
  {
    'title': 'Material de Escritório',
    'requester': 'Maria Aparecida da Silva',
    'cost': 300300300.00,
    'is_checked': false,
    'is_expanded': false,
  },
  {
    'title': 'Matéria-prima',
    'requester': 'Francisco Gonçalves Filho',
    'cost': 300300300.00,
    'is_checked': false,
    'is_expanded': false,
  },
];
