import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';

class NotificationListExample extends StatefulWidget {
  const NotificationListExample({Key? key}) : super(key: key);

  @override
  State<NotificationListExample> createState() => _NotificationListExampleState();
}

class _NotificationListExampleState extends State<NotificationListExample> {
  bool showLoadButton = true;
  bool showLoading = false;
  bool confirm = false;

  void _showSnackbar({
    required BuildContext context,
    required int index,
  }) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.success(
        message: 'Clicou na notificação ${index + 1}',
      ),
    );
  }

  late List<SeniorNotification> notifications = [
    SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: false,
      severity: SeniorNotificationListItemSeverity.warning,
      removalConfirmation: () async {
        await showDialog(
          context: context,
          builder: (context) {
            return SeniorModal(
              title: 'Excluir notificação?',
              content: 'Ao excluir esta notificação sua ação não poderá ser defeita.',
              defaultAction: SeniorModalAction(
                label: 'Voltar',
                action: () {
                  confirm = false;
                  Navigator.of(context).pop(context);
                },
              ),
              otherAction: SeniorModalAction(
                label: 'Excluir',
                action: () {
                  confirm = true;
                  Navigator.of(context).pop(context);
                },
                danger: true,
              ),
            );
          },
        );
        return Future.value(confirm);
      },
    ),
    const SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: true,
    ),
    const SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: true,
    ),
    const SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: false,
    ),
    const SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: true,
    ),
    const SeniorNotification(
      title: 'Espelho de ponto pendente',
      body: 'Você tem um espelho de ponto pendente',
      footer: '30/10/2021 - 08:42',
      isRead: true,
    ),
  ];

  void _clearNotifications() async {
    setState(() {
      notifications.clear();
      showLoadButton = false;
    });
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Notification List',
      child: Center(
        child: SeniorNotificationList(
          title: 'Últimas notificações',
          actionButtonLabel: 'Limpar',
          onTapActionButton: _clearNotifications,
          onNotificationTap: (index) {
            _showSnackbar(context: context, index: index);
          },
          loadButtonLabel: 'Carregar mais',
          notifications: notifications,
          isLoading: showLoading,
        ),
      ),
    );
  }
}
