import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class RadioButtonExample extends StatefulWidget {
  const RadioButtonExample({Key? key}) : super(key: key);

  @override
  _RadioButtonExampleState createState() => _RadioButtonExampleState();
}

class _RadioButtonExampleState extends State<RadioButtonExample> {
  bool _isDisabled = false;
  String _optionOne = 'morning';
  String _optionTwo = 'left';
  String _optionThree = 'brazil';

  void _changeOptionOne(dynamic value) {
    setState(() {
      _optionOne = value as String;
    });
  }

  void _changeOptionTwo(dynamic value) {
    setState(() {
      _optionTwo = value as String;
    });
  }

  void _changeOptionThree(dynamic value) {
    setState(() {
      _optionThree = value as String;
    });
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Radio Button',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Container(
            child: Column(
              children: [
                SeniorSwitch(
                  title: 'Habilitar botões',
                  value: !_isDisabled,
                  onChanged: (value) {
                    if (value == null) {
                      return;
                    }
                    setState(() {
                      _isDisabled = !value;
                    });
                  },
                  titlePosition: SeniorSwitchTitlePosition.right,
                ),
                Padding(
                  padding: const EdgeInsets.all(16.0),
                  child: Column(
                    children: [
                      Panel(
                        title: 'Normal',
                        child: Column(
                          children: [
                            SeniorRadioButton<dynamic>(
                              title: 'Matutino',
                              groupValue: _optionOne,
                              value: 'morning',
                              onChanged: _changeOptionOne,
                              disabled: _isDisabled,
                            ),
                            SeniorRadioButton<dynamic>(
                              title: 'Vespertino',
                              groupValue: _optionOne,
                              value: 'afternoon',
                              onChanged: _changeOptionOne,
                              disabled: _isDisabled,
                            ),
                            SeniorRadioButton<dynamic>(
                              title: 'Noturno',
                              groupValue: _optionOne,
                              value: 'night',
                              onChanged: _changeOptionOne,
                              disabled: _isDisabled,
                            ),
                          ],
                        ),
                      ),
                      Panel(
                        title: 'Botões em linha',
                        child: Row(
                          children: [
                            Expanded(
                              child: SeniorRadioButton<dynamic>(
                                title: 'Esquerda',
                                groupValue: _optionTwo,
                                value: 'left',
                                onChanged: _changeOptionTwo,
                                disabled: _isDisabled,
                              ),
                            ),
                            Expanded(
                              child: SeniorRadioButton<dynamic>(
                                title: 'Centro',
                                groupValue: _optionTwo,
                                value: 'center',
                                onChanged: _changeOptionTwo,
                                disabled: _isDisabled,
                              ),
                            ),
                            Expanded(
                              child: SeniorRadioButton<dynamic>(
                                title: 'Direita',
                                groupValue: _optionTwo,
                                value: 'right',
                                onChanged: _changeOptionTwo,
                                disabled: _isDisabled,
                              ),
                            ),
                          ],
                        ),
                      ),
                      Panel(
                        title: 'Botões em colunas separadas',
                        child: Column(
                          children: [
                            Row(
                              children: [
                                Expanded(
                                  child: SeniorRadioButton<dynamic>(
                                    title: 'Brasil',
                                    groupValue: _optionThree,
                                    value: 'brazil',
                                    onChanged: _changeOptionThree,
                                    disabled: _isDisabled,
                                  ),
                                ),
                                Expanded(
                                  child: SeniorRadioButton<dynamic>(
                                    title: 'Argentina',
                                    groupValue: _optionThree,
                                    value: 'argentina',
                                    onChanged: _changeOptionThree,
                                    disabled: _isDisabled,
                                  ),
                                ),
                              ],
                            ),
                            Row(
                              children: [
                                Expanded(
                                  child: SeniorRadioButton<dynamic>(
                                    title: 'Colômbia',
                                    groupValue: _optionThree,
                                    value: 'colombia',
                                    onChanged: _changeOptionThree,
                                    disabled: _isDisabled,
                                  ),
                                ),
                                Expanded(
                                  child: SeniorRadioButton<dynamic>(
                                    title: 'Peru',
                                    groupValue: _optionThree,
                                    value: 'peru',
                                    onChanged: _changeOptionThree,
                                    disabled: _isDisabled,
                                  ),
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
