import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class SnackbarExample extends StatelessWidget {
  const SnackbarExample({Key? key}) : super(key: key);

  void showSuccessSnackbar(BuildContext context) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.success(
        message: 'Operação realizada com sucesso',
        action: SeniorSnackBarAction(
          label: 'Repetir',
          onPressed: () {},
        ),
      ),
    );
  }

  void showMessageSnackbar(BuildContext context) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.message(
        message: 'Neste app têm muitos componentes',
        action: SeniorSnackBarAction(
          label: 'Ver',
          onPressed: () {},
        ),
      ),
    );
  }

  void showWarningSnackbar(BuildContext context) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.warning(
        message: 'Você não pode completar a operação neste horário',
        action: SeniorSnackBarAction(
          label: 'Fechar',
          onPressed: () {},
        ),
      ),
    );
  }

  void showErrorSnackbar(BuildContext context) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.error(
        message: 'Não foi possível carregar as informações',
        action: SeniorSnackBarAction(
          label: 'Repetir',
          onPressed: () {},
        ),
      ),
    );
  }

  void showErrorSnackbarNoButton(BuildContext context) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.error(
        message: 'Não foi possível carregar as informações',
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Snackbar',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Panel(
                title: 'Success Snackbar',
                child: Center(
                  child: SeniorButton(
                    label: 'Mostrar',
                    onPressed: () {
                      showSuccessSnackbar(context);
                    },
                  ),
                ),
              ),
              Panel(
                title: 'Message Snackbar',
                child: Center(
                  child: SeniorButton(
                    label: 'Mostrar',
                    onPressed: () {
                      showMessageSnackbar(context);
                    },
                  ),
                ),
              ),
              Panel(
                title: 'Warning Snackbar',
                child: Center(
                  child: SeniorButton(
                    label: 'Mostrar',
                    onPressed: () {
                      showWarningSnackbar(context);
                    },
                  ),
                ),
              ),
              Panel(
                title: 'Error Snackbar',
                child: Center(
                  child: SeniorButton(
                    label: 'Mostrar',
                    onPressed: () {
                      showErrorSnackbar(context);
                    },
                  ),
                ),
              ),
              Panel(
                title: 'Error Snackbar sem botão',
                child: Center(
                  child: SeniorButton(
                    label: 'Mostrar',
                    onPressed: () {
                      showErrorSnackbarNoButton(context);
                    },
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
