import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class SquareButtonsMenuExample extends StatefulWidget {
  const SquareButtonsMenuExample({Key? key}) : super(key: key);

  @override
  _SquareButtonsMenuExampleState createState() =>
      _SquareButtonsMenuExampleState();
}

class _SquareButtonsMenuExampleState extends State<SquareButtonsMenuExample> {
  bool checkOne = false;
  bool checkTwo = false;
  bool checkThree = false;
  bool checkFour = false;

  void showSnackBar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text('Opção "$message" selecionada'),
      ),
    );
  }

  void _showSnackbar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text(message),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Square Buttons Menu',
      child: SingleChildScrollView(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            Panel(
              title: 'In line',
              child: SeniorSquareButtonsMenu(
                items: [
                  SeniorSquareButtonsMenuItemData(
                    onTap: () {
                      showSnackBar(
                        context: context,
                        message: 'Emphasis button selected',
                      );
                    },
                    icon: FontAwesomeIcons.users,
                    text: 'Emphasis',
                    type: SeniorSquareButtonsMenuItemType.emphasis,
                  ),
                  SeniorSquareButtonsMenuItemData(
                    onTap: () {
                      showSnackBar(
                        context: context,
                        message: 'Emphasis negative button selected',
                      );
                    },
                    icon: FontAwesomeIcons.rightLeft,
                    text: 'Emphasis negative',
                    type: SeniorSquareButtonsMenuItemType.emphasisNegative,
                  ),
                  SeniorSquareButtonsMenuItemData(
                    onTap: () {
                      showSnackBar(
                        context: context,
                        message: 'Neutral button selected',
                      );
                    },
                    icon: FontAwesomeIcons.calendar,
                    text: 'Neutral',
                    type: SeniorSquareButtonsMenuItemType.neutral,
                  ),
                  SeniorSquareButtonsMenuItemData(
                    onTap: () {
                      showSnackBar(
                        context: context,
                        message: 'Neutral negative button selected',
                      );
                    },
                    icon: FontAwesomeIcons.calendar,
                    text: 'Neutral negative',
                    type: SeniorSquareButtonsMenuItemType.neutralNegative,
                  ),
                  SeniorSquareButtonsMenuItemData(
                    onTap: () {
                      showSnackBar(
                        context: context,
                        message: 'Ghost button selected',
                      );
                    },
                    icon: FontAwesomeIcons.plus,
                    text: 'Ghost',
                    type: SeniorSquareButtonsMenuItemType.ghost,
                  ),
                  SeniorSquareButtonsMenuItemData(
                    onTap: () {
                      showSnackBar(
                        context: context,
                        message: 'Ghost negative button selected',
                      );
                    },
                    icon: FontAwesomeIcons.plus,
                    text: 'Ghost negative',
                    type: SeniorSquareButtonsMenuItemType.ghostNegative,
                  ),
                ],
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(SeniorSpacing.normal),
              child: Panel(
                title: 'Grid',
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Container(
                      padding: const EdgeInsets.symmetric(vertical: 16.0),
                      child: Consumer<ThemeRepository>(
                        builder: (context, repository, child) => Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            SeniorText.body(
                                'Check Minha equipe: ${checkOne ? 'Marcado' : 'Desmarcado'}'),
                            SeniorText.body(
                                'Check Meus feedbacks: ${checkTwo ? 'Marcado' : 'Desmarcado'}'),
                            SeniorText.body(
                                'Check Minhas solicitações: ${checkThree ? 'Marcado' : 'Desmarcado'}'),
                            SeniorText.body(
                                'Check Requisição de férias: ${checkFour ? 'Marcado' : 'Desmarcado'}'),
                          ],
                        ),
                      ),
                    ),
                    Center(
                      child: SeniorSquareButtonsMenu.grid(
                        crossAxisCount: 3,
                        items: [
                          SeniorSquareButtonsMenuItemData.checkbox(
                              onTap: () {
                                showSnackBar(
                                  context: context,
                                  message: 'Emphasis button selected',
                                );
                              },
                              icon: FontAwesomeIcons.users,
                              text: 'Emphasis',
                              type: SeniorSquareButtonsMenuItemType.emphasis,
                              isChecked: checkOne,
                              withElevation: true,
                              onCheck: (check) {
                                _showSnackbar(
                                  context: context,
                                  message: 'Emphasis button checked',
                                );
                                if (check == null) {
                                  return;
                                }
                                setState(() {
                                  checkOne = check;
                                });
                              }),
                          SeniorSquareButtonsMenuItemData.checkbox(
                              onTap: () {
                                showSnackBar(
                                  context: context,
                                  message: 'Emphasis negative button selected',
                                );
                              },
                              icon: FontAwesomeIcons.rightLeft,
                              text: 'Emphasis negative',
                              type: SeniorSquareButtonsMenuItemType
                                  .emphasisNegative,
                              isChecked: checkTwo,
                              withElevation: true,
                              onCheck: (check) {
                                _showSnackbar(
                                  context: context,
                                  message: 'Emphasis negative button checked',
                                );
                                if (check == null) {
                                  return;
                                }
                                setState(() {
                                  checkTwo = check;
                                });
                              }),
                          SeniorSquareButtonsMenuItemData.checkbox(
                              onTap: () {
                                showSnackBar(
                                  context: context,
                                  message: 'Neutral button selected',
                                );
                              },
                              icon: FontAwesomeIcons.rightLeft,
                              text: 'Neutral',
                              type: SeniorSquareButtonsMenuItemType.neutral,
                              isChecked: checkThree,
                              withElevation: true,
                              onCheck: (check) {
                                _showSnackbar(
                                  context: context,
                                  message: 'Neutral button checked',
                                );
                                if (check == null) {
                                  return;
                                }
                                setState(() {
                                  checkThree = check;
                                });
                              }),
                          SeniorSquareButtonsMenuItemData(
                            onTap: () {
                              showSnackBar(
                                context: context,
                                message: 'Neutral negative selected',
                              );
                            },
                            icon: FontAwesomeIcons.calendarDays,
                            withElevation: true,
                            text: 'Neutral negative',
                            type:
                                SeniorSquareButtonsMenuItemType.neutralNegative,
                          ),
                          SeniorSquareButtonsMenuItemData.checkbox(
                              onTap: () {
                                showSnackBar(
                                  context: context,
                                  message: 'Neutral button selected',
                                );
                              },
                              icon: FontAwesomeIcons.plane,
                              text: 'Neutral',
                              type: SeniorSquareButtonsMenuItemType.neutral,
                              isChecked: checkFour,
                              withElevation: true,
                              onCheck: (check) {
                                _showSnackbar(
                                  context: context,
                                  message: 'Neutral button checked',
                                );
                                if (check == null) {
                                  return;
                                }
                                setState(() {
                                  checkFour = check;
                                });
                              }),
                          SeniorSquareButtonsMenuItemData(
                            onTap: () {
                              showSnackBar(
                                context: context,
                                message: 'Ghost button selected',
                              );
                            },
                            icon: FontAwesomeIcons.shieldHalved,
                            text: 'Ghost',
                            type: SeniorSquareButtonsMenuItemType.ghost,
                          ),
                          SeniorSquareButtonsMenuItemData(
                            onTap: () {
                              showSnackBar(
                                context: context,
                                message: 'Ghost negative selected',
                              );
                            },
                            icon: FontAwesomeIcons.plus,
                            text: 'Ghost negative',
                            type: SeniorSquareButtonsMenuItemType.ghostNegative,
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(SeniorSpacing.normal),
              child: Panel(
                title: 'Grid reduzida',
                child: Center(
                  child: SeniorSquareButtonsMenu.grid(
                    crossAxisCount: 9,
                    items: [
                      SeniorSquareButtonsMenuItemData(
                        onTap: () {
                          showSnackBar(
                            context: context,
                            message: 'Emphasis button selected',
                          );
                        },
                        icon: FontAwesomeIcons.users,
                        text: 'Emphasis',
                        type: SeniorSquareButtonsMenuItemType.emphasis,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: () {
                          showSnackBar(
                            context: context,
                            message: 'Emphasis negative button selected',
                          );
                        },
                        icon: FontAwesomeIcons.rightLeft,
                        text: 'Emphasis negative',
                        type: SeniorSquareButtonsMenuItemType.emphasisNegative,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: () {
                          showSnackBar(
                            context: context,
                            message: 'Neutral button selected',
                          );
                        },
                        icon: FontAwesomeIcons.rightLeft,
                        text: 'Neutral',
                        type: SeniorSquareButtonsMenuItemType.neutral,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: () {
                          showSnackBar(
                            context: context,
                            message: 'Neutral negative button selected',
                          );
                        },
                        icon: FontAwesomeIcons.calendarDays,
                        text: 'Neutral negative',
                        type: SeniorSquareButtonsMenuItemType.neutralNegative,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: () {
                          showSnackBar(
                            context: context,
                            message: 'Ghost button selected',
                          );
                        },
                        icon: FontAwesomeIcons.shieldHalved,
                        text: 'Ghost',
                        type: SeniorSquareButtonsMenuItemType.ghost,
                      ),
                      SeniorSquareButtonsMenuItemData(
                        onTap: () {
                          showSnackBar(
                            context: context,
                            message: 'Ghost negative button selected',
                          );
                        },
                        icon: FontAwesomeIcons.plus,
                        text: 'Ghost negative',
                        type: SeniorSquareButtonsMenuItemType.ghostNegative,
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
