import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class PageWrapper extends StatelessWidget {
  final String title;
  final Widget child;

  const PageWrapper({
    Key? key,
    required this.title,
    required this.child,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: const EdgeInsets.all(SeniorSpacing.normal),
      child: Center(
        child: Consumer<ThemeRepository>(
          builder: (context, repository, child) => Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Container(
                padding: const EdgeInsets.all(SeniorSpacing.normal),
                decoration: BoxDecoration(
                  borderRadius: const BorderRadius.all(
                      Radius.circular(SeniorRadius.huge)),
                  color: repository.isLightTheme()
                      ? SeniorColors.grayscale10
                      : SeniorColors.secondaryColor800,
                ),
                child: Center(
                  child: SeniorText.label(title),
                ),
              ),
              Flexible(
                child: this.child,
              ),
            ],
          ),
        ),
      ),
    );
  }
}
